Description Usage Arguments Value Examples
LLCT is a two-step self-contained gene-set analysis method which is developed to handle multiple longitudinal outcomes. Analysis of within-subject variation in the first step is followed by examining the between-subject variation utilizing Linear Combination Test (LCT) in the second step. This method is also applicable in analysis of time-course microarray data.
1 |
EXPR |
Gene Expressions — Row names:Subjects (single row per subject); Col names: Genes names. Note: The rownames of GS must be matched with colnames of EXPR and the unique values of the rownames of LongData must be matched with the rownames of EXPR. |
GS |
Gene Set Matrix — Row names: list of genes; Col names: list of selected gene sets; Cells: 1 (if gene of the row belongs to the gene set of the column) 0 (otherwise). Note: The rownames of GS must be matched with colnames of EXPR |
LongData |
Phenotypes and Covariates Data in Longitudinal format |
ID |
Name of ID variable in LongData |
time |
Vector of the names of time variables in LongData |
covariate |
name of covariate(s) in LongData |
phenotype |
name of phenotype in LongData |
familybased |
TRUE/FALSE indicating if the subjects are sharing families/pedigress Defaults to FALSE |
pedigree |
name of pedigree variable in LongData |
FIX.formula |
Formula of Phenotype~time model Defaults to "phenotype~time+covariate" |
RANDOM.formula |
Formula of random effects as lme function requires - required in case of related subjects Defaults to NULL |
nbPermutations |
Number of Permutations Defaults to 1000 |
family |
family of link function appropriate for the type of phenotype |
LLCT_Results |
geneset-specific p-values and q-values |
Step1_Coefs |
coefficients calculated in the first step using FIX_formula |
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 | data(data_for_LLCT)
#LLCT for unrelated subjects with two more complex time trend
LLCT(EXPR=EXPR, GS=GS, LongData=LongData, ID="ID",time=c("time","time2"), covariate=NULL,phenotype="phenotype",familybased=FALSE,pedigree=NULL,FIX.formula="~time+time2", RANDOM.formula=NULL,nbPermutations=1000)
#LLCT for unrelated subjects with a linear time trend
#LLCT(EXPR=EXPR, GS=GS, LongData=LongData, ID="ID",time=c("time"), covariate=NULL,phenotype="phenotype",familybased=FALSE,pedigree=NULL,FIX.formula="~time", RANDOM.formula=NULL,nbPermutations=1000)
#LLCT for unrelated subjects with adjustment for time dependent covariate
#LLCT(EXPR=EXPR, GS=GS, LongData=LongData, ID="ID",time=c("time"), covariate="covariate",phenotype="phenotype",familybased=FALSE,pedigree=NULL,FIX.formula="~time+covariate", RANDOM.formula=NULL,nbPermutations=1000)
#LLCT for unrelated subjects with binary phenotype
#LLCT(EXPR=EXPR, GS=GS, LongData=LongData, ID="ID",time=c("time"), covariate=NULL,phenotype="binary.phenotype",familybased=FALSE,pedigree=NULL,FIX.formula="~time", RANDOM.formula=NULL,nbPermutations=1000,family="binomial(link=logit)")
#LLCT for related subjects with adjustment for time dependent covariate
#LLCT(EXPR=EXPR, GS=GS, LongData=LongData, ID="ID",time=c("time"), covariate="covariate",phenotype="phenotype",familybased=FALSE,pedigree="pedigree",FIX.formula="~time+covariate", RANDOM.formula="~1|ID",nbPermutations=1000)
#LLCT for related subjects with adjustment for more complex time trend
#LLCT(EXPR=EXPR, GS=GS, LongData=LongData, ID="ID",time=c("time","time2"), covariate="covariate",phenotype="phenotype",familybased=FALSE,pedigree="pedigree",FIX.formula="~time+time2", RANDOM.formula="~1|ID",nbPermutations=1000)
#LLCT for unrelated subjects with two phenotypes
#LLCT(EXPR=EXPR, GS=GS, LongData=LongData, ID="ID",time=c("time"), covariate=NULL,phenotype=c("phenotype","phenotype2"),familybased=FALSE,pedigree=NULL,FIX.formula="~time", RANDOM.formula=NULL,nbPermutations=1000)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.